/* This is -*- C -*- */
/* vim: set sw=2: */
/* $Id: gnan.h,v 1.3 2001/01/16 23:36:39 trow Exp $ */

/*
 * gnan.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GNAN_H
#define _INC_GNAN_H

/* #include <gtk/gtk.h> */
#include <glib.h>
#include <math.h>
#include "guppi-defs.h"

BEGIN_GUPPI_DECLS;

#ifndef NAN
extern const double NAN;
#endif

gboolean g_isnan (double x);

void gnan_init (void);

END_GUPPI_DECLS;


#endif /* _INC_GNAN_H */

/* $Id: gnan.h,v 1.3 2001/01/16 23:36:39 trow Exp $ */
